[kde-solaris] Patches for kdeutils

Ian Reinhart Geiser kde-solaris@mail.kde.org
Tue Nov 12 12:24:04 2002


--Boundary-00=_CUO09RbueU8e6Yn
Content-Type: Text/Plain;
  charset="us-ascii"
Content-Transfer-Encoding: 7bit
Content-Description: clearsigned data
Content-Disposition: inline

-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Hi all, here are the patches for KDE utils :)
Please review.
Cheers
	-ian reinhart geiser
- -- 
========================================
I used to work in a fire hydrant factory.  You couldn't park anywhere
near the place.
		-- Steven Wright
========================================
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.0.7 (GNU/Linux)

iD8DBQE90OUCPy62TRm8dvgRAn4gAKCRc+NoSXeGUYNx7PcFC6RBNo0qTACg68rx
fG62gBUyk4A1wj0TgYxJGq0=
=8XOi
-----END PGP SIGNATURE-----

--Boundary-00=_CUO09RbueU8e6Yn
Content-Type: text/x-diff;
  charset="us-ascii";
  name="solaris-kdeutils.patch"
Content-Transfer-Encoding: 7bit
Content-Disposition: attachment; filename="solaris-kdeutils.patch"

Index: kcalc/kcalc.cpp
===================================================================
RCS file: /home/kde/kdeutils/kcalc/kcalc.cpp,v
retrieving revision 1.75
diff -u -r1.75 kcalc.cpp
--- kcalc/kcalc.cpp	2002/09/22 09:30:16	1.75
+++ kcalc/kcalc.cpp	2002/11/12 11:21:22
@@ -28,6 +28,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <math.h>
 
 #include <qlayout.h>
 #include <qobjectlist.h>
Index: klaptopdaemon/portable.cpp
===================================================================
RCS file: /home/kde/kdeutils/klaptopdaemon/portable.cpp,v
retrieving revision 1.30
diff -u -r1.30 portable.cpp
--- klaptopdaemon/portable.cpp	2002/10/03 10:17:39	1.30
+++ klaptopdaemon/portable.cpp	2002/11/12 11:21:25
@@ -1090,7 +1090,7 @@
 	return(1);
 }
 
-#elif  __NetBSD_APM__
+#elif defined(__NetBSD_APM__)
 
 #include <errno.h>
 #include <fcntl.h>
@@ -1381,18 +1381,15 @@
 //	explain to the user what they need to do if has_power_management() returned 0
 //	to get any software they lack
 //
-QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
+KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
-	QLabel* explain = new QLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels. If you want help porting these panels to work with it\nplease contact paul@taniwha.com."), parent);
+	KActiveLabel* explain = new KActiveLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels. If you want help porting these panels to work with it\nplease contact paul@taniwha.com."), parent);
       	explain->setMinimumSize(explain->sizeHint());       
 	return(explain);
 }
 
-//
-//	explain to the user what they need to do to get suspend/resume to work from user mode
-//
-QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
-{
+// // explain to the user what they need to do to get suspend/resume to work from user mode // Label
+QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent) {
  	QLabel* note = new QLabel(i18n(" "), parent);
         note->setMinimumSize(note->sizeHint()); 
 	return(note);

--Boundary-00=_CUO09RbueU8e6Yn--